from zope.interface import implements

from atreal.richfile.image.interfaces import IImageable

from atreal.richfile.qualifier.common import RFView
from atreal.richfile.qualifier.interfaces import IRFView
from atreal.richfile.image import RichFileImageMessageFactory as _

class RFImageView(RFView):
    
    plugin_interface = IImageable
    kss_id = 'image'
    viewlet_name = 'atreal.richfile.image.viewlet'
    update_message = _('The image preview has been updated.')
    active_message = _('Image preview activated.')
    unactive_message = _('Image preview un-activated.') 
    




from zope.interface.interfaces import IInterface
from zope.component import queryUtility

from atreal.richfile.image.interfaces import IImageable


def is_richfileimage_installed():
    """
    """
    return queryUtility(IInterface, name=u'atreal.richfile.image.IRichFileImageSite', default=False)


def buildAndStoreImage(obj, event):
    """
    """
    if not is_richfileimage_installed():
        return
    print "atreal.richfile.image: build and store image for %s" % ('/'.join(obj.getPhysicalPath()),)
    IImageable(obj).process()


def cleanImageData(obj, event):
    """
    """
    if not is_richfileimage_installed():
        return
    print "atreal.richfile.image: clean data for %s" % ('/'.join(obj.getPhysicalPath()),)
    IImageable(obj).cleanUp()



from zope.interface import implements

from zope.annotation.interfaces import IAnnotations

from atreal.richfile.image.interfaces import IImageable
from BTrees.OOBTree import OOBTree

import PIL.Image
from cStringIO import StringIO

from atreal.richfile.qualifier.common import RFPlugin

class ToImageableObject(RFPlugin):
    """
    """
    implements(IImageable)


    def process(self):
        """
        """
        print "atreal.richfile.image: processing..."
        self.setSubObject ('preview', self._scale (self.context.data, 400, 400))
        self.setSubObject ('thumb', self._scale (self.context.data, 128, 128))
        print "atreal.richfile.image: built and stored!"
  
    
    def _scale(self, data, w, h, default_format = 'PNG'):
        """ scale image """
        size = int(w), int(h)
        original_file=StringIO(data)
        image = PIL.Image.open(original_file)
        original_mode = image.mode
        if original_mode == '1':
            image = image.convert('L')
        elif original_mode == 'P':
            image = image.convert('RGBA')
        image.thumbnail(size, PIL.Image.ANTIALIAS)
        format = image.format and image.format or default_format
        if original_mode == 'P' and format == 'GIF':
            image = image.convert('P')
        thumbnail_file = StringIO()
        image.save(thumbnail_file, format, quality=88)
        thumbnail_file.seek(0)
        return thumbnail_file.read()



from plone.app.layout.viewlets import ViewletBase
from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile

from atreal.richfile.qualifier.browser.viewlets import RichfileViewlet
from atreal.richfile.image.interfaces import IImage
from atreal.richfile.image.interfaces import IImageable
from atreal.richfile.image.browser.controlpanel import IRichFileImageSchema
from atreal.richfile.image import RichFileImageMessageFactory as _

class ImageViewlet(RichfileViewlet):
    
    marker_interface = IImage
    plugin_interface = IImageable
    plugin_id = 'image'
    plugin_title = 'Image preview'
    controlpanel_interface = IRichFileImageSchema
    
        
    index = ViewPageTemplateFile("viewlet.pt")



from zope.interface import Interface

class IRichFileImageLayer(Interface):
    """ Marker interface that defines a Zope 3 browser layer.
    """

class IRichFileImageSite(Interface):
    """ Marker interface for sites with this product installed.
    """ 

class IImage(Interface):
    """
    """
    
class IImageable(Interface):
    """
    """



from zope.interface import Interface
from zope.component import adapts
from zope.interface import implements
from zope.schema import TextLine, Choice, List, Bool
from zope.formlib import form

from Products.CMFDefault.formlib.schema import ProxyFieldProperty
from Products.CMFDefault.formlib.schema import SchemaAdapterBase
from Products.CMFPlone.interfaces import IPloneSiteRoot
from Products.Five.browser.pagetemplatefile import ZopeTwoPageTemplateFile

from atreal.richfile.image import RichFileImageMessageFactory as _
from atreal.richfile.image.interfaces import IImageable
from plone.app.controlpanel.form import ControlPanelForm
from atreal.richfile.qualifier.common import RFControlPanel


class IRichFileImageSchema(Interface):
    """ """
    
    rf_image_collapsed = Bool(
        title=_(u"label_rf_image_collapsed",
                default=u"Display collapsed ?"),
        description=_(u"help_rf_image_collapsed",
                      default=u"Do you want the plugin's display to be collapsed ?"
                     ),
        default=False)

    
class RichFileImageControlPanelAdapter(SchemaAdapterBase):
    adapts(IPloneSiteRoot)
    implements(IRichFileImageSchema)

    rf_image_collapsed = ProxyFieldProperty(IRichFileImageSchema['rf_image_collapsed'])


    
class RichFileImageControlPanel(RFControlPanel):
    template = ZopeTwoPageTemplateFile('controlpanel.pt')
    form_fields = form.FormFields(IRichFileImageSchema)
    label = _("RichFileImage settings")
    description = _("RichFileImage settings for this site.")
    form_name = _("RichFileImage settings")
    plugin_iface = IImageable
    supported_ifaces = ('atreal.richfile.image.interfaces.IImage',)
    



from zope.i18nmessageid import MessageFactory
RichFileImageMessageFactory = MessageFactory('atreal.richfile.image')

from atreal.richfile.image.interfaces import IImage

def initialize(context):
    """Initializer called when used as a Zope 2 product."""
    try:
        from atreal.richfile.qualifier.registry import registerRFPlugin
    except:
        return
    
    supported_mimetypes = [
        'image/png',
        'image/gif',
        'image/jpeg',
        ]
    
    registerRFPlugin(IImage, supported_mimetypes)
    
